#ifndef FIREPROTECTIONSYSTEM_H
#define FIREPROTECTIONSYSTEM_H

enum {
	//Contstants per controlar els diferents estats pels que passa l'aplicació
	READY,
	ERROR,
	READ_BAT,
	READ_TEMP,
	ALARM_BAT,
	ALARM_TEMP,
	//Valor per defecte que té el timer amb el que s'envia l'alarma de bateria
	TIMER_MILI_SEND_BAT_ALARM = 60000,
	//Valor per defecte que té el timer amb el que s'envia l'alarma d'incendi
	TIMER_MILI_SEND_FIRE_ALARM = 1000,	
	//Valor per defecte que té el timer amb el que es llegeixen els sensors de bateria i de temperatura
	TIMER_MILI_READ = 500,
	//Valor per defecte que té el timer amb el que s'envien els valors dels sensors de bateria i de temperatura al receptor
	TIMER_MILI_SEND = 1000,
	//L'active message associat per enviar el missatge amb els valors dels sensors al receptor
	AM_SENSORMSG = 40,
	//L'active message associat per rebre el limit de temperatura especificat per l'usuari
	AM_LIMITTEMP = 41,
	//L'active message associat per enviar el missatge d'alarma de temperatura al receptor
	AM_ALARMTEMP = 42,
	//L'active message associat per enviar el missatge d'alarma de bateria al receptor
	AM_ALARMBATTERY = 43,
	//L'active message associat per rebre el temps (ms) amb el que es llegeixen els sensors de bateria i de temperatura
	AM_TIMERREADMSG = 44,
	//L'active message associat per rebre el temps (ms) amb el que s'envien els valors dels sensors de bateria i de temperatura al receptor
	AM_TIMERSENDMSG = 45,
	//Constant per indicar els milivolts amb els que treballa la mota
	VREFMILIVOLTS = 2560,
	//Constant per indicar el limit de bateria abans de saltar l'alarma de bateria baixa
	////605 equival a 3.5 Volts.
	////345 equival a 2 Volts	
	LIMIT_BAT=345,
	//Constant per indicar el limit de temperatura per defecte abans de saltar l'alarma d'incendi
	////600 equival a 100ºC
	////260 equival a 15ºC
	LIMIT_TEMP=600,
	//Constants per controlar quan s'activa o es desactiva l'alarma
	ALARMBAT_OK=1,
	ALARMBAT_KO=0,
	ALARMFIRE_OK=1,
	ALARMFIRE_KO=0
};

//Estructura que serveix per enviar al receptor les dades del sensors de bateria i de temperatura
typedef nx_struct SensorMsg {
	nx_uint8_t moteId;
	nx_uint16_t countsBat;
	nx_uint16_t vrefmilivolts;
	nx_uint16_t countsTemp;
} SensorMsg;

//Estructura que serveix perque el receptor pugui enviar el limit d'alarma d'incendi
typedef nx_struct LimitTemp {		
	nx_uint16_t countsTemp;
} LimitTemp;

//Estructura que serveix per inidicar al receptor l'alarma d'incendi
//Si es rep del receptor un missatge d'aquest tipus serà el missatge de confirmació d'alarma
typedef nx_struct AlarmTemp {
	nx_uint8_t moteId;
} AlarmTemp;

//Estructura que serveix per inidicar al receptor que la bateria s'està agotan
typedef nx_struct AlarmBattery {	 
	nx_uint8_t moteId;
} AlarmBattery;

//Estrcutura que serveix per actualitzar el període amb el que es llegeixen les dades dels sensors
typedef nx_struct TimerReadMsg{
	nx_uint32_t timerVal;
} TimerReadMsg;

//Estrcutura que serveix per actualitzar el període amb el que s'envien les dades dels sensors
typedef nx_struct TimerSendMsg{
	nx_uint32_t timerVal;
} TimerSendMsg;

#endif