package ws.standalone.cou.test;

import java.awt.Color;
import java.io.IOException;
import java.text.DecimalFormat;
import java.util.Timer;
import java.util.TimerTask;

import ws.standalone.cou.test.messages.AlarmBattery;
import ws.standalone.cou.test.messages.AlarmTemp;
import ws.standalone.cou.test.messages.LimitTemp;
import ws.standalone.cou.test.messages.SensorMsg;
import ws.standalone.cou.test.messages.TimerReadMsg;
import ws.standalone.cou.test.messages.TimerSendMsg;
import net.tinyos.message.Message;
import net.tinyos.message.MessageListener;
import net.tinyos.message.MoteIF;
import net.tinyos.packet.BuildSource;
import net.tinyos.packet.PhoenixSource;
import net.tinyos.util.PrintStreamMessenger;

public class FireProtectionSystemJava extends TimerTask implements MessageListener {

	/*
	 * Es declaren variables necessàries*/
	public static FireProtectionSystemJava instance = null;
	private static Timer timer = new Timer();

	static GraphicalUserInterface gui; 
	
	//MoteIF per rebre missatges provinents de la mota
	MoteIF mif;
	//MoteIF per enviar missatges a la mota
	static MoteIF mif2;
	
	/*
	 * Inici d'execució de l'aplicació
	 * Es crea l'interfície gràfica, es crea el phoenix per on hi haurà la comunicació amb les motes (SerialForwarder),
	 * s'instancien els missatges a rebre, s'inicia el timer per rebre els missatges*/
	public static void main (String args[]){
		gui = new GraphicalUserInterface();
		gui.launchFrame();
		
		println("Fire Protection System 1.0");
		println("----------------------------");

		instance = new FireProtectionSystemJava();
		
		PhoenixSource phoenix;
		phoenix = BuildSource.makePhoenix(PrintStreamMessenger.err);
		
		String source="sf@localhost:9002";	
		phoenix = BuildSource.makePhoenix(source, PrintStreamMessenger.err);
		
		instance.mif = new MoteIF(phoenix);
		FireProtectionSystemJava.mif2 = new MoteIF(phoenix);
		
		instance.mif.registerListener(new SensorMsg(), instance);
		instance.mif.registerListener(new AlarmBattery(), instance);
		instance.mif.registerListener(new AlarmTemp(), instance);
		
		
		timer.scheduleAtFixedRate(instance, 0, Long.parseLong(gui.retornaSendTimer())*10);

	}
	
	/*
	 * S'imprimeix l'String s pel textarea de la pantalla*/
	private static void println(String s){
		gui.TextShow(s);
		//System.out.println(s);
	}

	
	boolean firstTime=true;
	@Override
	/*
	 * void amb el que es controlen els missatges que es reben provinents de la mota
	 * */
	public void messageReceived(int to, Message m) {
		//si es el primer missatge que es rep s'engega el timer
		if(firstTime){
			firstTime=false;			
		}		
		if(m instanceof SensorMsg){
			SensorMsg sm = (SensorMsg) m;
			double lecturaVoltsBat = passarAVolts(sm.get_vrefmilivolts(),sm.get_countsBat())*2;
			double lecturaVoltsTemp = passarAVolts(sm.get_vrefmilivolts(),sm.get_countsTemp());
			double temperaturaCentigrads = (lecturaVoltsTemp-0.5)/0.01;			
			gui.DataShow(formatejarDouble(lecturaVoltsBat), formatejarDouble(temperaturaCentigrads));
			gui.alarmVcc(Color.decode("#009900"));
			//println(sm.toString());
		}
		if(m instanceof AlarmBattery){
			gui.alarmVcc(Color.RED);
			println("Alarm: Low Battery");
		}
		if(m instanceof AlarmTemp){
			gui.alarmTemp(Color.RED);
			println("Alarm: Fire!!");
		}
	}
	
	/*
	 * Mètode per convertir el valor de la mota a una escala coneguda*/
	private double passarAVolts(int vrefMilivolts, int counts){
		return (((double)counts)/1024)*(((double)vrefMilivolts)/1000);
	}
	
	/*
	 * Formateja el valor d*/
	private String formatejarDouble(double d){
		DecimalFormat df = new DecimalFormat("#0.00");
		return df.format(d);
	}
	
	/*
	 * Actualitza el timerRead de la mota emissora*/
	public static void actualitzaTimerRead(String timerRead){
		TimerReadMsg msg = new TimerReadMsg();
		msg.set_timerVal(Long.parseLong(timerRead));
		try {
			mif2.send(1,msg);
			println("Update timer read to "+timerRead+" ms");
		} catch (IOException e) {
			println("No s'ha pogut enviar el missatge TimerReadMsg a la mota 1");			
		}		
	}
	
	/*
	 * Actualitza el timerSend de la mota emissora*/
	public static void actualitzaTimerSend(String timerSend){
		TimerSendMsg msg = new TimerSendMsg();
		msg.set_timerVal(Long.parseLong(timerSend));
		try {
			mif2.send(1,msg);
			println("Update timer send to "+timerSend+" ms");
		} catch (IOException e) {
			println("No s'ha pogut enviar el missatge TimerSendMsg a la mota 1");			
		}		
	}
	
	/*
	 * Actualitza el límit de temperatura de la mota emissora*/
	public static void actualitzaLimitTemp(int limitTemp){
		LimitTemp msg = new LimitTemp();
		msg.set_countsTemp(limitTemp);
		//println(Integer.toString(limitTemp));
		try {
			mif2.send(1,msg);
			println("Update limit temperature to "+gui.retornaStringTemplimit()+" ºC");
		} catch (IOException e) {
			println("No s'ha pogut enviar el missatge LimitTemp a la mota 1");			
		}
	}
	
	/*
	 * Envia el missatge de confirmació d'alarma d'incendi*/	
	public static void confirmAlarmTemp(){
		AlarmTemp msg = new AlarmTemp();		
		try {
			mif2.send(1,msg);
			println("Confirm Temperature Alarm");
		} catch (IOException e) {
			println("No s'ha pogut enviar el missatge AlarmTemp a la mota 1");			
		}
	}
	
	@Override
	public void run() {

	}
}
